@@ -1,7 +1,7 @@
 package Log::ger::UseDataDump;
 
-our $DATE = '2017-06-28'; # DATE
-our $VERSION = '0.001'; # VERSION
+our $DATE = '2020-04-17'; # DATE
+our $VERSION = '0.002'; # VERSION
 
 use Data::Dump ();
 use Log::ger ();
@@ -24,7 +24,7 @@ Log::ger::UseDataDump - Use Data::Dump to dump data structures
 
 =head1 VERSION
 
-This document describes version 0.001 of Log::ger::UseDataDump (from Perl distribution Log-ger-UseDataDump), released on 2017-06-28.
+This document describes version 0.002 of Log::ger::UseDataDump (from Perl distribution Log-ger-UseDataDump), released on 2020-04-17.
 
 =head1 SYNOPSIS
 
@@ -54,7 +54,8 @@ L<Log::ger>
 
 L<Data::Dump>
 
-L<Log::ger::UseDataDumpColor>
+Other modules to set data dumper for Log::ger: L<Log::ger::UseDataPrinter>,
+L<Log::ger::UseDataDumpColor>, L<Log::ger::UseDataDumper>.
 
 =head1 AUTHOR
 
@@ -62,7 +63,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
